emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

emacs-29 d62b634d8f: ; * src/process.c (Fprocess_running_child_p): Doc f


From: Eli Zaretskii
Subject: emacs-29 d62b634d8f: ; * src/process.c (Fprocess_running_child_p): Doc fix.
Date: Sun, 25 Dec 2022 04:23:45 -0500 (EST)

branch: emacs-29
commit d62b634d8fcbdc553351b0e5c7cd61363e918ca4
Author: Eli Zaretskii <eliz@gnu.org>
Commit: Eli Zaretskii <eliz@gnu.org>

    ; * src/process.c (Fprocess_running_child_p): Doc fix.
---
 src/process.c | 11 +++++++----
 1 file changed, 7 insertions(+), 4 deletions(-)

diff --git a/src/process.c b/src/process.c
index 5144c5d6c9..cab8a1d5cf 100644
--- a/src/process.c
+++ b/src/process.c
@@ -6795,10 +6795,13 @@ emacs_get_tty_pgrp (struct Lisp_Process *p)
 
 DEFUN ("process-running-child-p", Fprocess_running_child_p,
        Sprocess_running_child_p, 0, 1, 0,
-       doc: /* Return non-nil if PROCESS has given the terminal to a
-child.  If the operating system does not make it possible to find out,
-return t.  If we can find out, return the numeric ID of the foreground
-process group.  */)
+       doc: /* Return non-nil if PROCESS has given control of its terminal to 
a child.
+If the operating system does not make it possible to find out, return t.
+If it's possible to find out, return the numeric ID of the foreground
+process group if PROCESS did give control of its terminal to a
+child process, and return nil if it didn't.
+
+PROCESS must be a real subprocess, not a connection.  */)
   (Lisp_Object process)
 {
   /* Initialize in case ioctl doesn't exist or gives an error,



reply via email to

[Prev in Thread] Current Thread [Next in Thread]